@@ -1,19 +1,17 @@
-/* ============================================================
- *
+/*
  * SPDX-FileCopyrightText: 2007-2011 Kare Sars <kare.sars@iki .fi>
  * SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 // Local includes
 #include "labeledgamma.h"
-#include "ksanebaseoption.h"
 
 #include <QGroupBox>
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
+#include <KSaneCore/Option>
 
 namespace KSaneIface
 {
@@ -24,23 +22,15 @@ LabeledGamma::LabeledGamma(QWidget *parent, const QString &text, int max)
     initGamma(text, max);
 }
 
-LabeledGamma::LabeledGamma(QWidget *parent, KSaneOption *option)
+LabeledGamma::LabeledGamma(QWidget *parent, KSaneCore::Option *option, QColor color)
     : KSaneOptionWidget(parent, option)
 {
 
     int max = option->maximumValue().toInt();
     initGamma(option->title(), max);
-    connect(this, &LabeledGamma::valuesChanged, option, &KSaneOption::setValue);
-    connect(option, &KSaneOption::valueChanged, this, &LabeledGamma::setValues);
-    if (option->name() == QString::fromUtf8(SANE_NAME_GAMMA_VECTOR_R)) {
-        setColor(Qt::red);
-    }
-    if (option->name() == QString::fromUtf8(SANE_NAME_GAMMA_VECTOR_G)) {
-        setColor(Qt::green);
-    }
-    if (option->name() == QString::fromUtf8(SANE_NAME_GAMMA_VECTOR_B)) {
-        setColor(Qt::blue);
-    }
+    connect(this, &LabeledGamma::valuesChanged, option, &KSaneCore::Option::setValue);
+    connect(option, &KSaneCore::Option::valueChanged, this, &LabeledGamma::setValues);
+    setColor(color);
     setToolTip(option->description());
 }
 
@@ -67,7 +57,7 @@ void LabeledGamma::initGamma(QString text, int max)
     m_brightSlider->setLabelWidth(labelMax);
     m_contrastSlider->setLabelWidth(labelMax);
     m_gammaSlider->setLabelWidth(labelMax);
-    
+
     m_maxValue = max;
 
     m_gammaDisplay = new GammaDisp(this, &m_brightness, &m_contrast, &m_gamma, max);
@@ -86,7 +76,7 @@ void LabeledGamma::initGamma(QString text, int max)
     connect(m_brightSlider, &LabeledSlider::valueChanged, this, &LabeledGamma::emitNewValues);
     connect(m_contrastSlider, &LabeledSlider::valueChanged, this, &LabeledGamma::emitNewValues);
     connect(m_gammaSlider, &LabeledSlider::valueChanged, this, &LabeledGamma::emitNewValues);
-    
+
     emitNewValues();
 }
 
@@ -108,20 +98,20 @@ void LabeledGamma::setValues(const QVariant &values)
         m_brightSlider->blockSignals(true);
         m_contrastSlider->blockSignals(true);
         m_gammaSlider->blockSignals(true);
-        
+
         m_brightness = copy.at(0).toInt();
         m_contrast = copy.at(1).toInt();
         m_gamma = copy.at(2).toInt();
-        
+
         m_brightSlider->setValue(m_brightness);
         m_contrastSlider->setValue(m_contrast);
         m_gammaSlider->setValue(m_gamma);
 
         emitNewValues();
-        
+
         m_brightSlider->blockSignals(false);
         m_contrastSlider->blockSignals(false);
-        m_gammaSlider->blockSignals(false); 
+        m_gammaSlider->blockSignals(false);
     }
 }
 
@@ -131,9 +121,9 @@ void LabeledGamma::emitNewValues()
     m_contrast = m_contrastSlider->value();
     m_gamma = m_gammaSlider->value();
     QVariantList values = { m_brightness, m_contrast, m_gamma };
-    
+
     m_gammaDisplay->update();
-    Q_EMIT valuesChanged(QVariant::fromValue(values));  
+    Q_EMIT valuesChanged(QVariant::fromValue(values));
 }
 
 bool LabeledGamma::getValues(int &brightness, int &contrast, int &gamma)
@@ -150,3 +140,5 @@ int LabeledGamma::maxValue()
 }
 
 }  // NameSpace KSaneIface
+
+#include "moc_labeledgamma.cpp"
